# acceptance_test_mh

import os
import sys

#testdir = os.path.dirname(__file__)
#testdir = os.path.realpath(__file__)
testdir = os.getcwd()
srcdir = '../..'
src_path =  os.path.abspath(os.path.join(testdir, srcdir))
sys.path.insert(0, os.path.abspath(src_path))

import unittest

from behave import *
import mh


# we put is required starting state
@given('we have installed mh')
def step_impl(context):
    import mh

# an action is taken
@when('we get the version')
def step_impl(context):
    context.version = mh.__version__

# the result is correct
@then('we have a version')
def step_impl(context):
    assert type(context.version) is type('')

# -----------------------------------------
@when('we get a mh variable')
def step_impl(context):
    context.v = mh.EG_VAR2

@then('we get the correct value')
def step_impl(context):
    assert (context.v == 'ABCD')

# -----------------------------------------
@when('we call a mh function')
def step_impl(context):
    context.r = mh.testFunction()

@then('we get the correct return')
def step_impl(context):
    assert (context.r == 'OK' )
# -----------------------------------------
@when('we create a mh object')
def step_impl(context):
    context.x = mh.Mh()


@then('we will have an mh object')
def step_impl(context):
    assert type(context.x) is type(mh.Mh())

# -----------------------------------------
@given('we have an mh object')
def step_impl(context):
    context.x = mh.Mh()

@when('we call a function')
def step_impl(context):
    context.y = context.x.runMh()

@then('we get the correct result')
def step_impl(context):
    assert ( context.y == 100 )





# eg_app.py

import sys
import logging
import logging.config
import yaml

#mypath = "/Users/markhallett/notgoogledrive/github/mh/src"
#mypath = "../../../src"
#sys.path.insert(0, mypath)

import mh

logging.config.dictConfig(yaml.load(open('logging_config.ymal', 'r'), Loader=yaml.FullLoader ))
logger = logging.getLogger(__name__)

if __name__ == '__main__':
    logger.info("START")
    logger.info(mh)
    try:
        1/0
    except ZeroDivisionError as e:
        logger.error('eg', exc_info = True)

    logger.info(mh.__version__)
    mh.Mh().runMh()

    logger.debug("END")



# unit_test_mh_eg.py

import os
import sys

#testdir = os.path.dirname(__file__)
#testdir = os.path.realpath(__file__)
testdir = os.getcwd()
srcdir = '../..'
src_path =  os.path.abspath(os.path.join(testdir, srcdir))
sys.path.insert(0, os.path.abspath(src_path))

import unittest
from unittest import mock
#import patch

from mhlib import eg

class TestMhlibEg(unittest.TestCase):
    def test_var(self):
        self.assertEqual(eg.EG_VAR, 'abcd')

    def test_func(self):
        rtn = eg.test()
        self.assertEqual(rtn,'ok')

class TestMhEg(unittest.TestCase):
    def test_runMh(self):
        x = eg.MhEg()
        y = x.runMhEg()
        self.assertEqual( y, 10 )

    @mock.patch('mhlib.eg.MhEg.slow', return_value=3)
    def test_slow(self, mocked_func ):
        x = eg.MhEg()
        rtn = x.slow()
        self.assertEqual(rtn,3)

    @mock.patch('mhlib.l2.l2.L2Mh.slow', return_value=5)
    def test_external_func(self, mocked_func):
        x = eg.MhEg()
        rtn = x.call_external_func()
        self.assertEqual(rtn,5)


if __name__ == '__main__':
    unittest.main()



from setuptools import setup
from setuptools import find_packages

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name="mh",
    Version="0.0.33",
    author="Mark Hallett",
    author_email="mh@markhallett.co.uk",
    description="A small example package",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/markhallett/mh",
    project_urls={
        "Documentation": "https://markhallett.github.io/mh",
    },
    packages=find_packages('src'),
    #packages=[],
    py_modules=["mh"],
    package_dir={'':'src'},
    install_requires=[],
    extras_require={"dev":[
                            "pycrunch-trace==0.1.5",
                            "behave==1.2.6",
                           ],},
    scripts=['README.md',],
    classifiers=[
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
         ],
)



# test1.py


import os
import sys

testdir = os.getcwd()
srcdir = '../..'
src_path =  os.path.abspath(os.path.join(testdir, srcdir))
sys.path.insert(0, os.path.abspath(src_path))


import mh
from mhlib import eg
# import mhlib.eg as eg
from  mhlib.l2 import l2



def test():
    print ('#'*40)
    print ('file under test:', mh)
    print ('version:', mh.__version__)
    print ('doc:', mh.__doc__)
    print ('dir:', dir(mh))
    print ('.'*10)
    print ('file under test:', eg)
    print ('doc:', eg.__doc__)
    print ('dir:', dir(eg))
    print ('.'*10)
    print ('file under test:', l2)
    print ('doc:', l2.__doc__)
    print ('dir:', dir(l2))


if __name__ == '__main__':
    test()
    print ('Done')



# acceptance_test_example

import os
import sys

#testdir = os.path.dirname(__file__)
#testdir = os.path.realpath(__file__)
testdir = os.getcwd()
srcdir = '../..'
src_path =  os.path.abspath(os.path.join(testdir, srcdir))
sys.path.insert(0, os.path.abspath(src_path))

import unittest

from behave import *

import time

@given('we have behave installed')
def step_impl(context):
    pass

@when('we implement a test')
def step_impl(context):
    assert True is not False

@then('behave will test it for us!')
def step_impl(context):
    assert context.failed is False


# ----------------------
@given('a set up')
def step_impl(context):
    pass

@when('we run the test')
def step_impl(context):
    time.sleep(2)

@then('it will eventually pass')
def step_impl(context):
    pass

@when('we run the current test')
def step_impl(context):
    pass

@then('it will pass')
def step_impl(context):
    pass

# ---------------------
@given('a starting point two')
def step_impl(context):
    pass

@given('a starting point three')
def step_impl(context):
    pass

@when('we multiply by three')
def step_impl(context):
    time.sleep(2)

@when('we multiply by two')
def step_impl(context):
    time.sleep(2)

@then('the product will be six')
def step_impl(context):
    pass

# ----------------------------------

@given('a lot of data')
def step_impl(context):
     context.s = context.text

@when('we add more data')
def step_impl(context):
    context.s += context.text

@then('we have even more data')
def step_impl(context):
     assert (context.s == context.text)


# ----------------------------------

@given('a table')
def step_impl(context):
    context.t = context.table

@when('we calculate the total value')
def step_impl(context):
    context.total_value = 0
    for row in context.t:
        fruit, value, items = row
        context.total_value += int(value) * int(items)

@when('we calculate the total items')
def step_impl(context):
    context.total_items = 0
    for row in context.t:
        fruit, value, items = row
        context.total_items += int(items)

@then('we get the totals')
def step_impl(context):
    expected_results = context.table

    expected_totals = {}
    for total, value in expected_results:
       expected_totals[total] = int(value)

    # generally a bad idea to test 2 things in one test
    assert (context.total_value == expected_totals['value'] )
    assert (context.total_items == expected_totals['items'] )


# ------------------------------
@given('a value "{v}"')
def step_impl(context, v):
    context.v = int(v)

@when('squared')
def step_impl(context):
    context.r = context.v * context.v

@then ('the result is "{r}"' )
def step_impl(context, r):
    r = int(r)
    assert( context.r == r)
